## What's Changed - BIG AND BEAUTIFUL VERSION

> 如果在之前版本使用了 Skill，这次更新之后**需要重新配置** Skill Runtime 相关选项。

### 新增
- 🔥 新增未来任务系统（Future Tasks）。给 AstrBot 布置的未来任务，让 AstrBot 能够在某一时刻自动唤醒，帮你完成任务。详见 [主动任务](https://docs.astrbot.app/use/proactive-agent.html) 。（实验性） ([#4697](https://github.com/AstrBotDevs/AstrBot/issues/4831))
- 🔥 新增子代理（SubAgent）编排器。（实验性）([#4697](https://github.com/AstrBotDevs/AstrBot/issues/4831))
- 🔥 AstrBot 目前可以直接通过调用 tool 将图片 / 文件推送给用户，大大提高交互效果。
- 新增 Computer Use 运行时配置，以融合 Skill 和 Sandbox 配置 ([#4831](https://github.com/AstrBotDevs/AstrBot/issues/4831))
- 新增主题自定义功能，可设置主色与辅色
- 支持在配置页下人格对话框的编辑人格 ([#4826](https://github.com/AstrBotDevs/AstrBot/issues/4826))
- 支持开关 “追踪” 功能；支持在系统配置中设置是否将日志写入 log 文件 ([#4822](https://github.com/AstrBotDevs/AstrBot/issues/4822))

### 修复
- ‼️ 修复 ChatUI 图片、思考等显示异常问题。
- ‼️ 修复 Skill 上传到 Sandbox 后未自动解压导致 Agent 无法读取的问题。
- ‼️ 修复配置特定插件集时 MCP 工具被过滤的问题 ([#4825](https://github.com/AstrBotDevs/AstrBot/issues/4825))
- ‼️ 移除 ChatUI 自带的让 LLM 最后提出问题的 prompt ([#4824](https://github.com/AstrBotDevs/AstrBot/issues/4824))
- ‼️ 修复 WebUI 在上传 Skill 失败后仍显示成功消息的 bug ([#4768](https://github.com/AstrBotDevs/AstrBot/issues/4768))
- 修复 MCP 服务器无法重命名的问题 ([#4766](https://github.com/AstrBotDevs/AstrBot/issues/4766))
- 修复插件的 tool 无法在 WebUI 管理行为中看到来源的问题 ([#4776](https://github.com/AstrBotDevs/AstrBot/issues/4776))
- ‼️ 修复 skill-like 的 tool 模式下，调用 tool 失败的问题 ([#4775](https://github.com/AstrBotDevs/AstrBot/issues/4775))

### 优化

- WebUI 整体 UI 效果优化
- 部分 Dialog 标题样式统一

## What's Changed (EN)

### New Features
- Introduce CronJob system with one-time tasks and enhanced dashboard management
- Add theme customization with primary & secondary color options
- Add computer-use runtime config for skills sandbox execution ([#4831](https://github.com/AstrBotDevs/AstrBot/issues/4831))
- Add edit button to persona selector dialog ([#4826](https://github.com/AstrBotDevs/AstrBot/issues/4826))
- Add trace logging toggle and configuration UI ([#4822](https://github.com/AstrBotDevs/AstrBot/issues/4822))
- Add proactive-messaging capability with cron-tool trigger
- Implement SubAgent orchestrator with configurable tool-management policies
- Support resolving sandbox file paths and auto-download when necessary
- Add embedded image & audio styles in MessagePartsRenderer
- Introduce i18n foundation
- Persist agent-interaction history
- Add user notifications for file-download success/removal

### Bug Fixes
- Improve ghost-plugin detection accuracy
- Add error handling to prevent ghost-plugin crashes
- Prevent skills bundle from overwriting existing files
- Fix skills bundle unzip failure inside sandbox
- Fix MCP tools being filtered when specific plugin set configured ([#4825](https://github.com/AstrBotDevs/AstrBot/issues/4825))
- Merge ChatUI persona pop-up into default persona ([#4824](https://github.com/AstrBotDevs/AstrBot/issues/4824))
- Fix reasoning block style
- Add missing comma in truncate_and_compress hint
- Fix frontend still showing success message ([#4768](https://github.com/AstrBotDevs/AstrBot/issues/4768))
- Fix unable to rename MCP server ([#4766](https://github.com/AstrBotDevs/AstrBot/issues/4766))
- Remove leftover sandbox runtime handling in skill upload ([#4798](https://github.com/AstrBotDevs/AstrBot/issues/4798))
- Fix handler module path construction ([#4776](https://github.com/AstrBotDevs/AstrBot/issues/4776))
- Fix skill-like tool invocation error ([#4775](https://github.com/AstrBotDevs/AstrBot/issues/4775))

### Improvements
- Runtime hints & refined UI in skills management
- Performance and UX improvements on cron-job page
- General WebUI performance boost
- Group tools by plugin in dropdown
- Consistent dialog titles with padding and text styles
- Code formatting unified (ruff format)
- Bump version to 4.13.2

### Others
- Remove obsolete reminder code
- Extract main-agent module for better architecture
- Merge AstrBot_skill branch changes